ACQUIA
======

Acequia is a python package to facilitate the data flow of groundwater 
measurement. It's primary aim is to provide some tools to easely read
and write common file formats and to calculate statistics from 
groundwater time series. Acequia is written from the perspective of
Dutch groundwater practitioners who deal with files from Dinoloket, 
Menyanthes and Pastas.

 